diff artifacts/src/main/java/org/dive4elements/river/artifacts/services/MainValuesService.java @ 8202:e4606eae8ea5

sed src/**/*.java 's/logger/log/g'
author Sascha L. Teichmann <teichmann@intevation.de>
date Fri, 05 Sep 2014 12:58:17 +0200
parents 11bc2d6a2059
children 30b1ddadf275
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/artifacts/services/MainValuesService.java	Fri Sep 05 12:54:58 2014 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/artifacts/services/MainValuesService.java	Fri Sep 05 12:58:17 2014 +0200
@@ -41,8 +41,8 @@
  */
 public class MainValuesService extends D4EService {
 
-    /** The logger that is used by this service.*/
-    private static Logger logger = Logger.getLogger(MainValuesService.class);
+    /** The log that is used by this service.*/
+    private static Logger log = Logger.getLogger(MainValuesService.class);
 
     /** The XPath that points to the river definition of the incoming request.*/
     public static final String XPATH_RIVER = "/art:mainvalues/art:river/text()";
@@ -63,7 +63,7 @@
     }
 
     private static final Document error(String msg) {
-        logger.debug(msg);
+        log.debug(msg);
         return XMLUtils.newDocument();
     }
 
@@ -74,7 +74,7 @@
         GlobalContext context,
         CallMeta      callMeta
     ) {
-        logger.debug("MainValuesService.process");
+        log.debug("MainValuesService.process");
 
         this.callMeta = callMeta;
 
@@ -108,7 +108,7 @@
     protected River getRequestedRiver(Document data)
     throws    NullPointerException
     {
-        logger.debug("MainValuesService.getRequestedRiver");
+        log.debug("MainValuesService.getRequestedRiver");
 
         String riverStr = XMLUtils.xpathString(
             data, XPATH_RIVER, ArtifactNamespaceContext.INSTANCE);
@@ -131,7 +131,7 @@
      * @return the start and end point.
      */
     protected double[] getRequestedStartEnd(Document data, River river) {
-        logger.debug("MainValuesService.getStartEnd");
+        log.debug("MainValuesService.getStartEnd");
 
         String startStr = XMLUtils.xpathString(
             data, XPATH_START, ArtifactNamespaceContext.INSTANCE);
@@ -147,15 +147,15 @@
             double start = Double.parseDouble(startStr);
             double end   = Double.parseDouble(endStr);
 
-            if (logger.isDebugEnabled()) {
-                logger.debug("Found start: " + start);
-                logger.debug("Found end: " + end);
+            if (log.isDebugEnabled()) {
+                log.debug("Found start: " + start);
+                log.debug("Found end: " + end);
             }
 
             return new double[] { start, end };
         }
         catch (NumberFormatException nfe) {
-            logger.warn(nfe, nfe);
+            log.warn(nfe, nfe);
             return river.determineMinMaxDistance();
         }
     }
@@ -173,16 +173,16 @@
      */
     protected List<MainValue> getMainValues(River river, Gauge gauge) {
 
-        if (logger.isDebugEnabled()) {
-            logger.debug("MainValuesService.buildMainValues");
-            logger.debug("River: " + river.getName());
-            logger.debug("Gauge: " + gauge.getName());
+        if (log.isDebugEnabled()) {
+            log.debug("MainValuesService.buildMainValues");
+            log.debug("River: " + river.getName());
+            log.debug("Gauge: " + gauge.getName());
         }
 
         List<MainValue> mainValues = gauge.getMainValues();
 
-        if (logger.isDebugEnabled()) {
-            logger.debug(mainValues.size() + " main values found.");
+        if (log.isDebugEnabled()) {
+            log.debug(mainValues.size() + " main values found.");
         }
 
         return mainValues;
@@ -195,7 +195,7 @@
         List<MainValue> mainValues,
         Object          context)
     {
-        logger.debug("MainValuesService.buildDocument");
+        log.debug("MainValuesService.buildDocument");
 
         Document doc = XMLUtils.newDocument();
 
@@ -233,7 +233,7 @@
         Gauge    gauge,
         Object   context)
     {
-        logger.debug("MainValuesService.appendMetaInformation");
+        log.debug("MainValuesService.appendMetaInformation");
 
         ElementCreator cr = new ElementCreator(
             doc,
@@ -274,7 +274,7 @@
         Integer         riverId,
         Object          context)
     {
-        logger.debug("MainValuesService.appendMainValues");
+        log.debug("MainValuesService.appendMainValues");
 
         ElementCreator cr = new ElementCreator(
             doc,

http://dive4elements.wald.intevation.org